(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     78431,       1931]*)
(*NotebookOutlinePosition[     79153,       1956]*)
(*  CellTagsIndexPosition[     79109,       1952]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Raytraceing Special Relativity", "Title"],

Cell["W\[UDoubleDot]rzburg", "Subtitle"],

Cell["\<\
code and documentation by jph - download from www.hakenberg.de\
\>", "Text"],

Cell[CellGroupData[{

Cell["General Topics", "Section"],

Cell[CellGroupData[{

Cell["Lorentz transformation", "Subsubsection"],

Cell[BoxData[
    \(\(Plot[1\/\@\(1 - x\^2\), {x, 0, 1}];\)\)], "Input"],

Cell[BoxData[{
    \(X = \[CapitalTau]\[FivePointedStar][x, 3]\), "\[IndentingNewLine]", 
    \(V = \(1\/\@\(1 - X . X\)\) \[ScriptF][X, \(-1\)]\)}], "Input"],

Cell[BoxData[{\(y = { .6,  .7,  .1};\), "\[IndentingNewLine]", \(y // 
      tex\), "\[IndentingNewLine]", \(\@\(y . 
          y\)\), "\[IndentingNewLine]", \(e = 
      V\[SmallCircle]y\), "\[IndentingNewLine]", 
    RowBox[{"SetPrecision", "[", 
      RowBox[{
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", "0", "0", \(x\_1\)},
                  {"0", "0", "0", \(x\_2\)},
                  {"0", "0", "0", \(x\_3\)},
                  {\(x\_1\), \(x\_2\), \(x\_3\), "0"}
                  }], ")"}], "\[SmallCircle]", "e"}], "]"}], ",", "3"}], 
      "]"}]}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"\[Alpha]", "=", 
        RowBox[{
          RowBox[{"EXP", "[", 
            RowBox[{"(", GridBox[{
                  {"0", "0", "0", \(x\_1\)},
                  {"0", "0", "0", \(x\_2\)},
                  {"0", "0", "0", \(x\_3\)},
                  {\(x\_1\), \(x\_2\), \(x\_3\), "0"}
                  }], ")"}], "]"}], "//", "\[ScriptS]"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] // MF\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Refraction", "Subsubsection"],

Cell[BoxData[{
    \(\(n = {0, 1};\)\), "\[IndentingNewLine]", 
    \(\[Nu] = 
      0.413394;  (*diamond*) \[IndentingNewLine]r = {1, \(-1\)};\), "\
\[IndentingNewLine]", 
    \(\(r = r/Norm[r] // N;\)\), "\[IndentingNewLine]", 
    \(\(ct1 = r . n;\)\), "\[IndentingNewLine]", 
    \(\(If[ct1 > 0, 
        Print["\<out\>"]; \[Nu] = 
          1/\[Nu], \(Print["\<in\>"];\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<coefficient \>", \[Nu]];\)\), "\[IndentingNewLine]", 
    \(\(ct22 = 
        1 - \(\[Nu]\^2\) \((1 - ct1\^2)\);\)\), "\[IndentingNewLine]", 
    \(If[ct22 \[GreaterEqual] 
        0, \[IndentingNewLine]ct2 = \@ct22; \[IndentingNewLine]Print["\<ct1 \
\>", ct1 // N]; \[IndentingNewLine]Print["\<ct2 \>", 
        ct2 // N]; \[IndentingNewLine]Print["\<my \>", 
        o = \[Nu]\ r + \((Sign[
                      ct1]\ ct2 - \[Nu]\ ct1)\)\ n];\[IndentingNewLine], \
\[IndentingNewLine]o = 
        r - 2  ct1\ n; \[IndentingNewLine]Print["\<total reflection\>"];\
\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(o\), "\[IndentingNewLine]", 
    \(Norm[o]\)}], "Input"],

Cell[BoxData[
    \(1/{1.0002926, 1.333, 1.5, 1.544, 2.419}\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Collision Detection", "Section"],

Cell[CellGroupData[{

Cell["TriangleT vs. ray", "Subsubsection"],

Cell[BoxData[{
    \(\(L = Id[3, 1];\)\), "\[IndentingNewLine]", 
    \(ray = {\(- .75\),  .3, \(-1\)}\), "\[IndentingNewLine]", 
    \(ray = \[ScriptF][ray/Norm[ray], \(-1\)]\), "\[IndentingNewLine]", 
    \(L . ray . ray\)}], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  " corners of triangle"
}], "Text"],

Cell[BoxData[
    \(o + \[Tau]\ r \[Equal] 
        p\_1 + \[Lambda]\ v + \(\[Mu]\_1\) \((p\_2 - 
                p\_1)\) + \(\[Mu]\_2\) \((p\_3 - p\_1)\) // Expand\)], "Input"],

Cell[BoxData[
    \(o - 
          p\_1 \[Equal] \(-\[Tau]\)\ r + \[Lambda]\ v + \(\[Mu]\_1\) \((p\_2 \
- p\_1)\) + \(\[Mu]\_2\) \((p\_3 - p\_1)\) // Expand\)], "Input"],

Cell[BoxData[
    \(\(\[ScriptG] = Id[3, 1];\)\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {\(-1\), "0", "1", \(-5\), "0", "5", "1", \(-1\), "0", "0"},
              {".5", ".5", ".5", \(-1\), \(-1\), \(-1\), "1", "0", "1", "2"},
              {\(-1\), "1", \(-1\), \(-5\), "5", \(-5\), "0", "1", \(-1\), 
                "0"},
              {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"0", "50", "100", "100", "150", "200", "100", "200", "250", 
                "300"},
              {"0", "100", "0", "0", "100", "0", "100", "0", "100", "50"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(v = \[CapitalMu]Normalize[\[ScriptG], \
{0, 0, 0, 1}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{"(", GridBox[{
                {"0", "0", 
                  "0", \(v\[LeftDoubleBracket]1\[RightDoubleBracket]\)},
                {"0", "0", 
                  "0", \(v\[LeftDoubleBracket]2\[RightDoubleBracket]\)},
                {"0", "0", 
                  "0", \(v\[LeftDoubleBracket]3\[RightDoubleBracket]\)},
                {\(v\[LeftDoubleBracket]1\[RightDoubleBracket]\), \(v\
\[LeftDoubleBracket]2\[RightDoubleBracket]\), \(v\[LeftDoubleBracket]3\
\[RightDoubleBracket]\), "0"}
                }], ")"}], "]"}]}], 
      ";", \(T // MF\)}], "\[IndentingNewLine]", \(X = 
        T . X;\), "\[IndentingNewLine]", \(X // MF\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "4", "5", "8"},
              {"2", "5", "6", "9"},
              {"3", "6", "7", "10"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ";"}]}], "Input"],

Cell[BoxData[{
    \(\(Off[Part::partd];\)\), "\[IndentingNewLine]", 
    \(os = OpenWrite["\<c:/collide.c\>"]\), "\[IndentingNewLine]", 
    \(\(cnt = 0;\)\), "\[IndentingNewLine]", 
    \(\(Module[{A, c1, c2, 
            c3}, \[IndentingNewLine]A = \[ScriptT][{\(-{ray\
\[LeftDoubleBracket]1\[RightDoubleBracket], 
                    ray\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    ray\[LeftDoubleBracket]3\[RightDoubleBracket], 
                    ray\[LeftDoubleBracket]4\[RightDoubleBracket]}\), v, 
                X\[LeftDoubleBracket]
                    All, #1\[LeftDoubleBracket]2\[RightDoubleBracket]\
\[RightDoubleBracket] - 
                  X\[LeftDoubleBracket]
                    All, #1\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket], 
                X\[LeftDoubleBracket]
                    All, #1\[LeftDoubleBracket]3\[RightDoubleBracket]\
\[RightDoubleBracket] - 
                  X\[LeftDoubleBracket]
                    All, #1\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket]}]; \[IndentingNewLine]\(WriteString[
                os, "\<sol[\>", \(cnt++\), "\<]=\>", #1, "\<;\n\>"] &\) /@ \
\[ScriptF][\[IndentingNewLine]CForm[
                SetPrecision[Det[A] // Chop, 5]], \[IndentingNewLine]CForm /@ 
                SetPrecision[\((\(Det[
                            A]\ Inv[
                              A] . \(({pos\[LeftDoubleBracket]1\
\[RightDoubleBracket], pos\[LeftDoubleBracket]2\[RightDoubleBracket], 
                                  pos\[LeftDoubleBracket]3\
\[RightDoubleBracket], pos\[LeftDoubleBracket]4\[RightDoubleBracket]} - 
                                X\[LeftDoubleBracket]
                                  All, #1\[LeftDoubleBracket]1\
\[RightDoubleBracket]\[RightDoubleBracket])\) // Chop\) // \[ScriptS])\), 
                  5]]; \[IndentingNewLine]WriteString[
            os, "\<\n\>"];\[IndentingNewLine]] &\) /@ \[ScriptT][
        T]\), "\[IndentingNewLine]", 
    \(\(WriteString[
        os, "\<#define TRIANGLES \>", \[ScriptL][\[ScriptT][
            T]], "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(Close[os]\)}], "Input"],

Cell[BoxData[{
    \(os = OpenWrite["\<c:/texture.c\>"]\), "\[IndentingNewLine]", 
    \(\(cnt = 0;\)\), "\[IndentingNewLine]", 
    \(\(Module[{k}, \[IndentingNewLine]Table[\[IndentingNewLine]WriteString[
              os, "\<tex[\>", \(cnt++\), "\<]=\>", 
              CForm[SetPrecision[
                  L\[LeftDoubleBracket]
                    k, #1\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket], 5]], "\<;\n\>"]; \[IndentingNewLine]WriteString[
              os, "\<tex[\>", \(cnt++\), "\<]=\>", 
              CForm[SetPrecision[
                  L\[LeftDoubleBracket]
                      k, #1\[LeftDoubleBracket]2\[RightDoubleBracket]\
\[RightDoubleBracket] - 
                    L\[LeftDoubleBracket]
                      k, #1\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket], 5]], "\<;\n\>"]; \[IndentingNewLine]WriteString[
              os, "\<tex[\>", \(cnt++\), "\<]=\>", 
              CForm[SetPrecision[
                  L\[LeftDoubleBracket]
                      k, #1\[LeftDoubleBracket]3\[RightDoubleBracket]\
\[RightDoubleBracket] - 
                    L\[LeftDoubleBracket]
                      k, #1\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket], 5]], "\<;\n\>"];\[IndentingNewLine], {k, 
              2}]; \[IndentingNewLine]\(WriteString[
                os, "\<tex[\>", \(cnt++\), "\<]=\>", 
                CForm[SetPrecision[#1, 
                    5]], "\<;\n\>"] &\) \
/@ \[IndentingNewLine]\[CapitalMu]Normalize[Id[3], 
              Cross[X\[LeftDoubleBracket]{1, 2, 
                      3}, #1\[LeftDoubleBracket]2\[RightDoubleBracket]\
\[RightDoubleBracket] - 
                  X\[LeftDoubleBracket]{1, 2, 
                      3}, #1\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket], \[IndentingNewLine]X\[LeftDoubleBracket]{1, 2, 
                      3}, #1\[LeftDoubleBracket]3\[RightDoubleBracket]\
\[RightDoubleBracket] - 
                  X\[LeftDoubleBracket]{1, 2, 
                      3}, #1\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket]]]; \[IndentingNewLine]WriteString[
            os, "\<//----\n\>"];\[IndentingNewLine]] &\) /@ \[ScriptT][
        T]\), "\[IndentingNewLine]", 
    \(Close[os]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["ConeT vs. Point", "Subsubsection"],

Cell[BoxData[{
    RowBox[{"X", "=", 
      RowBox[{"(", GridBox[{
            {"0", "5", "0", "0"},
            {"2", \(-5\), "0", "0"}
            }], ")"}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          "\[IndentingNewLine]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0", "0", "0", "1"},
                  {"0", ".3", "0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], 
      ";"}], "\[IndentingNewLine]", \(V // MF\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[DoubleStruckCapitalC]", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], ";"}]}], "Input"],

Cell[BoxData[{
    RowBox[{"X", "=", 
      RowBox[{"(", GridBox[{
            {"5", "5", "0", "0"}
            }], ")"}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          "\[IndentingNewLine]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"0", \(- .8\), "0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], 
      ";"}], "\[IndentingNewLine]", \(V // MF\)}], "Input"],

Cell[BoxData[{
    \(\(\[ScriptG] = Id[3, 1];\)\), "\[IndentingNewLine]", 
    \(\(P = \[CapitalTau]\[FivePointedStar][p, 
          4];\)\), "\[IndentingNewLine]", 
    \(eqs = \[IndentingNewLine]\(\((\[ScriptG] . \[CapitalTau]\
\[FivePointedStar][x, 4] . \[CapitalTau]\[FivePointedStar][x, 
                  4])\)\[SmallCircle]\((X\[LeftDoubleBracket]#1\
\[RightDoubleBracket] + \[Tau]\ V\[LeftDoubleBracket]#1\[RightDoubleBracket] \
- {pnt\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  pnt\[LeftDoubleBracket]2\[RightDoubleBracket], 
                  pnt\[LeftDoubleBracket]3\[RightDoubleBracket], 
                  pnt\[LeftDoubleBracket]4\[RightDoubleBracket]})\) &\) /@ 
        Range[\[ScriptL][X]]\), "\[IndentingNewLine]", 
    \(sol = 
      Factor[\[ScriptF][\(\[Tau] /. Solve[#1 \[Equal] 0, \[Tau]] &\) /@ 
              eqs]] /. {\[IndentingNewLine]pnt\[LeftDoubleBracket]1\
\[RightDoubleBracket]\^2 \[Rule] 
            pnt\[LeftDoubleBracket]1\[RightDoubleBracket]\ pnd\
\[LeftDoubleBracket]1\[RightDoubleBracket], \[IndentingNewLine]pnt\
\[LeftDoubleBracket]2\[RightDoubleBracket]\^2 \[Rule] 
            pnt\[LeftDoubleBracket]2\[RightDoubleBracket]\ pnd\
\[LeftDoubleBracket]2\[RightDoubleBracket], \[IndentingNewLine]pnt\
\[LeftDoubleBracket]3\[RightDoubleBracket]\^2 \[Rule] 
            pnt\[LeftDoubleBracket]3\[RightDoubleBracket]\ pnd\
\[LeftDoubleBracket]3\[RightDoubleBracket], \[IndentingNewLine]pnt\
\[LeftDoubleBracket]4\[RightDoubleBracket]\^2 \[Rule] 
            pnt\[LeftDoubleBracket]4\[RightDoubleBracket]\ pnd\
\[LeftDoubleBracket]4\[RightDoubleBracket]}\)}], "Input"],

Cell[BoxData[{
    \(\(Off[Part::partd];\)\), "\[IndentingNewLine]", 
    \(os = OpenWrite["\<c:/lights.c\>"]\), "\[IndentingNewLine]", 
    \(\(cnt = 1;\)\), "\[IndentingNewLine]", 
    \(\(Module[{n, k}, \[IndentingNewLine]n = 
            cnt; \[IndentingNewLine]WriteString[
            os, "\<par[\>", \(cnt++\), "\<]=\>", 
            CForm[SetPrecision[
                Chop[sol\[LeftDoubleBracket]2  #1 - 1\[RightDoubleBracket]], 
                5]], "\<;\n\>"]; \
\[IndentingNewLine]Table[\[IndentingNewLine]WriteString[
              os, "\<par[\>", \(cnt++\), "\<]=\>", \[IndentingNewLine]CForm[
                SetPrecision[
                  Chop[X\[LeftDoubleBracket]#1, k\[RightDoubleBracket] + 
                        par\[LeftDoubleBracket]
                            n\[RightDoubleBracket]\ V\[LeftDoubleBracket]#1, 
                            k\[RightDoubleBracket] - 
                        pnt\[LeftDoubleBracket]
                          k\[RightDoubleBracket]] // \[ScriptS], 
                  5]], \[IndentingNewLine]"\<;\n\>"], {k, 
              4}]; \[IndentingNewLine]WriteString[
            os, "\<//----\n\>"]; \[IndentingNewLine]n = 
            cnt; \[IndentingNewLine]WriteString[
            os, "\<par[\>", \(cnt++\), "\<]=\>", 
            CForm[SetPrecision[
                Chop[sol\[LeftDoubleBracket]2  #1\[RightDoubleBracket]], 
                5]], "\<;\n\>"]; \
\[IndentingNewLine]Table[\[IndentingNewLine]WriteString[
              os, "\<par[\>", \(cnt++\), "\<]=\>", \[IndentingNewLine]CForm[
                SetPrecision[
                  Chop[X\[LeftDoubleBracket]#1, k\[RightDoubleBracket] + 
                      par\[LeftDoubleBracket]
                          n\[RightDoubleBracket]\ V\[LeftDoubleBracket]#1, 
                          k\[RightDoubleBracket] - 
                      pnt\[LeftDoubleBracket]k\[RightDoubleBracket]], 
                  5]], \[IndentingNewLine]"\<;\n\>"], {k, 
              4}]; \[IndentingNewLine]WriteString[
            os, "\<//----\n\>"];\[IndentingNewLine]] &\) /@ 
      Range[\[ScriptL][X]]\), "\[IndentingNewLine]", 
    \(\(WriteString[
        os, "\<#define LIGHTS \>", \[ScriptL][
          X], "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(Close[os]\)}], "Input"],

Cell[BoxData[{
    \(\(Off[Part::partd];\)\), "\[IndentingNewLine]", 
    \(os = OpenWrite["\<c:/color.c\>"]\), "\[IndentingNewLine]", 
    \(\(cnt = 0;\)\), "\[IndentingNewLine]", 
    \(\(Module[{n, 
            k}, \[IndentingNewLine]Table[\[IndentingNewLine]\(WriteString[
                os, "\<col[\>", \(cnt++\), "\<]=\>", 
                CForm[SetPrecision[\[DoubleStruckCapitalC]\[LeftDoubleBracket]\
#1, k\[RightDoubleBracket], 5]], "\<;\n\>"];\), {k, 
              3}]; \[IndentingNewLine]Table[\[IndentingNewLine]\(WriteString[
                os, "\<col[\>", \(cnt++\), "\<]=\>", 
                CForm[SetPrecision[
                    V\[LeftDoubleBracket]#1, k\[RightDoubleBracket], 
                    5]], "\<;\n\>"];\), {k, 
              4}]; \[IndentingNewLine]WriteString[
            os, "\<//----\n\>"];\[IndentingNewLine]] &\) /@ 
      Range[\[ScriptL][X]]\), "\[IndentingNewLine]", 
    \(Close[os]\)}], "Input"],

Cell["From these two, we choose the smaller one. Example:", "Text"],

Cell[BoxData[{
    \(\(subst = \[ScriptF][{p\_1, p\_2, p\_3} \[ShortRightArrow] {3, 3, 
              0}, {v\_1, v\_2, v\_3, v\_4} \[ShortRightArrow] {0, 0, 0, 1}, 
          X \[ShortRightArrow] {3, 4, 
              0, \(-4\)}];\)\), "\[IndentingNewLine]", 
    \(\(eqs = \((\[ScriptG] . X . 
                X)\)\[SmallCircle]\((X - {p\_1, p\_2, p\_3, 
                  0} - \[Tau]\ {v\_1, v\_2, v\_3, v\_4})\) /. 
          subst;\)\), "\[IndentingNewLine]", 
    \(Solve[eqs \[Equal] 0, \[Tau]]\)}], "Input"],

Cell[BoxData[{
    \(\[CapitalMu]Norm[\[ScriptG], 
      V = {1, 0, 1, 1}]\), "\[IndentingNewLine]", 
    \(\(subst = \[ScriptF][{p\_1, p\_2, p\_3} \[ShortRightArrow] {3, 3, 
              0}, {v\_1, v\_2, v\_3, v\_4} \[ShortRightArrow] V, 
          X \[ShortRightArrow] {3, 4, 
              0, \(-4\)}];\)\), "\[IndentingNewLine]", 
    \(\(eqs = \((\[ScriptG] . X . 
                X)\)\[SmallCircle]\((X - {p\_1, p\_2, p\_3, 
                  0} - \[Tau]\ {v\_1, v\_2, v\_3, v\_4})\) /. 
          subst;\)\), "\[IndentingNewLine]", 
    \(Solve[eqs \[Equal] 0, \[Tau]]\)}], "Input"],

Cell[BoxData[
    \(\[ScriptG] = DiagonalMatrix[{1, 1, 1, \(-1\)}]\)], "Input"],

Cell[BoxData[{
    \(X = \[CapitalTau]\[FivePointedStar][x, 4]\), "\[IndentingNewLine]", 
    \(eqs = \((\[ScriptG] . X . 
            X)\)\[SmallCircle]\(({q\_1, q\_2, q\_3, 
              0} + \[Tau]\ {u\_1, u\_2, u\_3, 
                u\_4} - \[CapitalTau]\[FivePointedStar][h, 
              4])\)\), "\[IndentingNewLine]", 
    \(\(eqs // tex;\)\), "\[IndentingNewLine]", 
    \(\[Tau] /. \(Solve[
          eqs \[Equal] 
            0, \[Tau]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], \
"Input"],

Cell[BoxData[
    \(\((X - {q\_1, q\_2, q\_3, 
          0} - \[Tau]\ {u\_1, u\_2, u\_3, u\_4})\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Release 3", "Section"],

Cell[CellGroupData[{

Cell["Models EXECUTER", "Subsubsection"],

Cell[BoxData[{\(Off[Part::partd];\), "\[IndentingNewLine]", \(\[ScriptG] = 
        Id[3, 1];\), "\[IndentingNewLine]", \(\[ScriptCapitalR] = 
        Id[4];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[GothicS]\[GothicO]31", "=", 
        RowBox[{"(", GridBox[{
              {"0", "0", "0", \(x\_1\)},
              {"0", "0", "0", \(x\_2\)},
              {"0", "0", "0", \(x\_3\)},
              {\(x\_1\), \(x\_2\), \(x\_3\), "0"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(Mopen := 
        Module[{}, \[IndentingNewLine]os = 
            OpenWrite["\<c:/Dokumente und Einstellungen/Administrator/Eigene \
Dateien/cpp/specrel/tri_cld.c\>"]; 
          cns = 0; \[IndentingNewLine]ot = 
            OpenWrite["\<c:/Dokumente und Einstellungen/Administrator/Eigene \
Dateien/cpp/specrel/tri_mat.c\>"]; 
          cnt = 0; \[IndentingNewLine]num = 
            0;];\), "\[IndentingNewLine]", \(Mappend := \(Module[{\
\[ScriptCapitalT], \[ScriptCapitalX], A, k, 
                lst}, \[IndentingNewLine]\[ScriptCapitalT] = 
                EXP[\[GothicS]\[GothicO]31\[SmallCircle]
                    V\[LeftDoubleBracket]#1\[RightDoubleBracket]]; \
\[IndentingNewLine]\[ScriptCapitalX] = \[ScriptCapitalT] . 
                  X\[LeftDoubleBracket]All, 
                    T\[LeftDoubleBracket]#1\[RightDoubleBracket]\
\[RightDoubleBracket]; \[IndentingNewLine]A = \[ScriptT][{\(-{ray\
\[LeftDoubleBracket]1\[RightDoubleBracket], 
                        ray\[LeftDoubleBracket]2\[RightDoubleBracket], 
                        ray\[LeftDoubleBracket]3\[RightDoubleBracket], 
                        ray\[LeftDoubleBracket]4\[RightDoubleBracket]}\), 
                    V\[LeftDoubleBracket]#1\[RightDoubleBracket], \
\[ScriptCapitalX]\[LeftDoubleBracket]All, 
                        2\[RightDoubleBracket] - \[ScriptCapitalX]\
\[LeftDoubleBracket]All, 
                        1\[RightDoubleBracket], \[IndentingNewLine]\
\[ScriptCapitalX]\[LeftDoubleBracket]All, 
                        3\[RightDoubleBracket] - \[ScriptCapitalX]\
\[LeftDoubleBracket]All, 1\[RightDoubleBracket]}]; \[IndentingNewLine]If[
                Chop[Det[A]] =!= 0, \(num++\); \[IndentingNewLine]lst = 
                  CForm /@ \[ScriptF][\[IndentingNewLine]SetPrecision[
                        Chop[Det[A]], 7], 
                      SetPrecision[
                        Simplify[
                          Chop[\[IndentingNewLine]Det[
                                A]\ Inv[
                                  A] . \(({pos\[LeftDoubleBracket]1\
\[RightDoubleBracket], pos\[LeftDoubleBracket]2\[RightDoubleBracket], 
                                      pos\[LeftDoubleBracket]3\
\[RightDoubleBracket], 
                                      pos\[LeftDoubleBracket]4\
\[RightDoubleBracket]} - \[ScriptCapitalX]\[LeftDoubleBracket]All, 
                                      1\[RightDoubleBracket])\)\
\[IndentingNewLine]]], 7]]; \[IndentingNewLine]\(WriteString[
                      os, "\<cld[\>", \(cns++\), "\<]=\>", #1, "\<;\n\>"] &\) \
/@ lst\[LeftDoubleBracket]{1, 
                      2}\[RightDoubleBracket]; \[IndentingNewLine]WriteString[
                  os, "\<if (cld[\>", cns - 1, "\<]*cld[\>", 
                  cns - 2, "\<]>0) {\n\>"]; \[IndentingNewLine]\(WriteString[
                      os, "\<cld[\>", \(cns++\), "\<]=\>", #1, "\<;\n\>"] &\) \
/@ lst\[LeftDoubleBracket]{3, 4, 
                      5}\[RightDoubleBracket]; \[IndentingNewLine]WriteString[
                  os, "\<}\n\>"]; \[IndentingNewLine]WriteString[
                  os, "\<//----\n\>"]; \[IndentingNewLine]\(WriteString[
                      ot, "\<mat[\>", \(cnt++\), "\<]=\>", #1, "\<;\n\>"] &\) \
/@ \[IndentingNewLine]\(CForm /@ \[ScriptF][
                      SetPrecision[
                        Chop[\[IndentingNewLine]Table[{\[IndentingNewLine]L\
\[LeftDoubleBracket]k, T\[LeftDoubleBracket]#1, 
                                  1\[RightDoubleBracket]\[RightDoubleBracket],\
 \[IndentingNewLine]L\[LeftDoubleBracket]k, 
                                  T\[LeftDoubleBracket]#1, 
                                    2\[RightDoubleBracket]\
\[RightDoubleBracket] - L\[LeftDoubleBracket]k, 
                                  T\[LeftDoubleBracket]#1, 
                                    1\[RightDoubleBracket]\
\[RightDoubleBracket], \[IndentingNewLine]L\[LeftDoubleBracket]k, 
                                  T\[LeftDoubleBracket]#1, 
                                    3\[RightDoubleBracket]\
\[RightDoubleBracket] - L\[LeftDoubleBracket]k, 
                                  T\[LeftDoubleBracket]#1, 
                                    1\[RightDoubleBracket]\
\[RightDoubleBracket]}, {k, 2}]], 7]]\); \[IndentingNewLine]\(WriteString[
                      ot, "\<mat[\>", \(cnt++\), "\<]=\>", #1, "\<;\n\>"] &\) \
/@ \[IndentingNewLine]\(CForm /@ \[ScriptF][
                      SetPrecision[
                        Chop[\[IndentingNewLine]\[CapitalMu]Normalize[Id[3], 
                            Cross[\[IndentingNewLine]\[ScriptCapitalX]\
\[LeftDoubleBracket]{1, 2, 3}, 
                                  2\[RightDoubleBracket] - \[ScriptCapitalX]\
\[LeftDoubleBracket]{1, 2, 3}, 
                                  1\[RightDoubleBracket], \[ScriptCapitalX]\
\[LeftDoubleBracket]{1, 2, 3}, 
                                  3\[RightDoubleBracket] - \[ScriptCapitalX]\
\[LeftDoubleBracket]{1, 2, 3}, 1\[RightDoubleBracket]]]\[IndentingNewLine]], 
                        7]]\); \[IndentingNewLine]\(WriteString[
                      ot, "\<mat[\>", \(cnt++\), "\<]=\>", #1, "\<;\n\>"] &\) \
/@ \[IndentingNewLine]\(CForm /@ \[ScriptF][
                      SetPrecision[
                        Chop[\[ScriptCapitalM]\[LeftDoubleBracket]#1\
\[RightDoubleBracket]], 7]]\); \[IndentingNewLine]WriteString[
                  ot, "\<//----\n\>"];\[IndentingNewLine]]; \
\[IndentingNewLine]If[Mod[num, 50] \[Equal] 0, 
                Print[num]];\[IndentingNewLine]] &\) /@ 
          Range[\[ScriptL][T]];\), "\[IndentingNewLine]", \(Mclose := 
        Module[{}, \[IndentingNewLine]WriteString[os, "\<#define TRI_NUM \>", 
            num, "\<\n\>"]; \[IndentingNewLine]WriteString[
            os, "\<#define TRI_CLD \>", 
            5, "\<\n\>"]; \[IndentingNewLine]WriteString[
            os, "\<#define TRI_MAT \>", 
            14, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define TEX_AFF_X \>", 
            0, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define TEX_MU1_X \>", 
            1, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define TEX_MU2_X \>", 
            2, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define TEX_AFF_Y \>", 
            3, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define TEX_MU1_Y \>", 
            4, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define TEX_MU2_Y \>", 
            5, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define NORMAL_X \>", 
            6, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define NORMAL_Y \>", 
            7, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define NORMAL_Z \>", 
            8, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define MATT \>", 
            9, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define REFL \>", 
            10, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define REFR \>", 
            11, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define V1oV2 \>", 
            12, "\<\n\>"]; \[IndentingNewLine]WriteString[
            ot, "\<#define CMAP \>", 13, "\<\n\>"]; \[IndentingNewLine]Close[
            os]; \[IndentingNewLine]Close[
            ot];];\), "\[IndentingNewLine]", \(Mimport := 
        Module[{}, \[IndentingNewLine]X = \[ScriptCapitalR] . \[ScriptT][
                Partition[
                  Import["\<c:/specrel/\>" <> fn <> "\<.ver\>", "\<List\>"], 
                  4]]; \[IndentingNewLine]L = 
            Partition[
                Import["\<c:/specrel/\>" <> fn <> "\<.tex\>", "\<List\>"], 
                2] // \[ScriptT]; \[IndentingNewLine]T = 
            Partition[
              Import["\<c:/specrel/\>" <> fn <> "\<.top\>", "\<List\>"], 
              3]; \[IndentingNewLine]\[ScriptCapitalM] = 
            Partition[
              Import["\<c:/specrel/\>" <> fn <> "\<.ref\>", "\<List\>"], 
              5]; \[IndentingNewLine]V = 
            Table[\[CapitalMu]Normalize[\[ScriptG], 
                v . \[ScriptT][\[ScriptCapitalR]]], {\[ScriptL][
                  T]}]; \[IndentingNewLine]Mappend; \[ScriptL][
            T]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["6 two lenses behind glass", "Subsubsection"],

Cell[BoxData[{\(Mopen;\), "\[IndentingNewLine]", \(\[Omega] = {0,  .1, 
          0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(d = \(-1\); 
    h = 7;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"\[ScriptCapitalR]", ".", 
          RowBox[{"(", GridBox[{
                {\(-10\), \(-10\), "10", "10", \(-10\), \(-10\), "10", 
                  "10", \(-10\), \(-10\), "10", 
                  "10", \(-5\), \(-0\), \(-0\), \(-5\), "0", "0"},
                {"0", "0", "0", "0", "0", "h", "h", "0", "h", "h", "h", "h", 
                  "1", "1", "6", "1", "1", "6"},
                {"d", "5", "5", "d", "d", "d", "d", "d", "d", "5", "5", "d", 
                  "3", "3", "3", "2.9", "2.9", "2.5"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
                  "0", "0", "0", "0", "0", "0"}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"0", "0", "12", "12", "0", "6", "6", "0", "0", "0", "12", "12",
                 "0", "0", "100", "0", "0", "100"},
              {"100", \(100 + 12\), \(100 + 12\), "100", "100", "100", "112", 
                "112", "100", "112", "112", "100", "300", "400", "400", "300",
                 "400", "400"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"3", "4", "1"},
              {"5", "7", "6"},
              {"7", "5", "8"},
              {"9", "11", "10"},
              {"11", "9", "12"},
              {"13", "15", "14"},
              {"16", "17", "18"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] =  .8; 
    d = 1 - \[Alpha];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {".2", ".1", ".7", \(1/ .7\), "0"},
              {".2", ".1", ".7", \(1/ .7\), "0"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ";", 
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], ";"}], "\[IndentingNewLine]", \(Mappend;\)}], "Input"],

Cell[BoxData[{\(\[Omega] = {0, \(- .05\), 0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(fn = "\<scry1\>"; 
    v = { .8,  .1, 0, 1};\), "\[IndentingNewLine]", 
  "Mimport", "\[IndentingNewLine]", \(fn = "\<scry2\>"; 
    v = {\(- .8\), \(- .1\), 0, 1};\), "\[IndentingNewLine]", 
  "Mimport", "\[IndentingNewLine]", \(Mclose;\)}], "Input"],

Cell["Lights", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {\(-5\), "1", "0", "0"},
              {"5", "6", "0", "0"},
              {"0", "3", "2", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          "\[IndentingNewLine]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(0/10\), \(0/10\), \(0/10\), "1"},
                  {"0", \(0/10\), "0", "1"},
                  {"0", "0", "0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[DoubleStruckCapitalC]", "=", 
        RowBox[{"1.3", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.", "1.", ".1"},
                  {".3", "1", ".3"},
                  {"1", "0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], 
      ";"}], "\[IndentingNewLine]", \(\[ScriptCapitalO] = {0, 2, 
          0};\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["2 Ship thru gate of Hankang", "Subsubsection"],

Cell[BoxData[{\(Mopen;\), "\[IndentingNewLine]", \(\[Omega] = {0, \(-\[Pi]\)/
            6, 0. };\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(d = \(-10\); e = 10; 
    h = 7;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"\[ScriptCapitalR]", ".", 
          RowBox[{"(", GridBox[{
                {\(-e\), \(-e\), "e", "e", \(-e\), \(-e\), "e", "e"},
                {"0", "0", "0", "0", "h", "h", "h", "h"},
                {"d", "10", "10", "d", "d", "10", "10", "d"},
                {"0", "0", "0", "0", "0", "0", "0", "0"}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"300", "300", "320", "320", "200", "200", "300", "300"},
              {"200", "220", "220", "200", "0", "100", "100", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"3", "4", "1"},
              {"5", "7", "6"},
              {"7", "5", "8"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] =  .3; 
    d = 1 - \[Alpha];\), "\[IndentingNewLine]", \(\[Mu] =  .85;\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ";", 
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "\[Mu]", "1"},
                    {"0", "0", "\[Mu]", "1"},
                    {"0", "0", "\[Mu]", "1"},
                    {"0", "0", "\[Mu]", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], ";"}], "\[IndentingNewLine]", \(Mappend;\)}], "Input"],

Cell[BoxData[{
    \(fn = "\<myship\>"; v = {0, 0, \(- .85\), 1};\), "\[IndentingNewLine]", 
    \(Mimport\), "\[IndentingNewLine]", 
    \(fn = "\<mygate\>"; v = {0, 0,  .85, 1};\), "\[IndentingNewLine]", 
    \(Mimport\), "\[IndentingNewLine]", 
    \(\(Mclose;\)\)}], "Input"],

Cell[BoxData[
    \(\(Mclose;\)\)], "Input"],

Cell["Lights", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {"3.5", "6", "1", "0"},
              {\(-5\), "4", \(-2\), "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          "\[IndentingNewLine]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(0/10\), \(0/10\), \(0/10\), "1"},
                  {"0", "0", "0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[DoubleStruckCapitalC]", "=", 
        RowBox[{"1.25", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {".8", "1.2", ".8"},
                  {"1.8", ".5", ".8"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], 
      ";"}], "\[IndentingNewLine]", \(\[ScriptCapitalO] = {0, 1};\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1 Flight thru arch", "Subsubsection"],

Cell[BoxData[{\(Mopen;\), "\[IndentingNewLine]", \(\[Omega] = {0, 0, 
          0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(d = \(-15\); 
    e = 15;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"\[ScriptCapitalR]", ".", 
          RowBox[{"(", GridBox[{
                {\(-e\), \(-e\), "e", "e", \(-e\), \(-e\), "e", "e"},
                {"0", "0", "0", "0", "0", "e", "e", "0"},
                {"d", "5", "5", "d", "d", "d", "d", "d"},
                {"0", "0", "0", "0", "0", "0", "0", "0"}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"100", "100", "200", "200", "200", "200", "300", "300"},
              {"0", "100", "100", "0", "200", "300", "300", "200"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"3", "4", "1"},
              {"5", "7", "6"},
              {"7", "5", "8"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] =  .70; 
    d = 1 - \[Alpha];\), "\[IndentingNewLine]", \(\[Mu] =  .7;\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"1", "0", "0", "1.", "0"},
              {"1", "0", "0", "1.", "0"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ";", 
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "\[Mu]", "1"},
                    {"0", "0", "\[Mu]", "1"},
                    {"0", "0", "\[Mu]", "1"},
                    {"0", "0", "\[Mu]", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Mappend;\), "\[IndentingNewLine]", \(fn \
= "\<arch\>"; v = {0, 0, \[Mu], 1}; 
    Mimport\), "\[IndentingNewLine]", \(Mclose;\)}], "Input"],

Cell["Lights", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {".5", "2.5", "2", "0"},
              {\(-2\), "10", \(-2\), "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          "\[IndentingNewLine]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(0/10\), \(0/10\), \(0/10\), "1"},
                  {"0", "0", "0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[DoubleStruckCapitalC]", "=", 
        RowBox[{"1.25", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.", "1.", "1."},
                  {".8", "0.", ".8"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], 
      ";"}], "\[IndentingNewLine]", \(\[ScriptCapitalO] = {0, 0};\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["5 American police car", "Subsubsection"],

Cell[BoxData[{\(Mopen;\), "\[IndentingNewLine]", \(\[Omega] = {0, 0, 
          0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(d = \(-3\);\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"\[ScriptCapitalR]", ".", 
          RowBox[{"(", GridBox[{
                {\(-10\), \(-10\), "10", "10", \(-10\), \(-10\), "10", "10"},
                {"0", "0", "0", "0", "0", "10", "10", "0"},
                {"d", "5", "5", "d", "d", "d", "d", "d"},
                {"0", "0", "0", "0", "0", "0", "0", "0"}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"0", "0", "12", "12", "0", "0", "12", "0"},
              {"100", \(100 + 12\), \(100 + 12\), "100", 
                "100", \(100 + 12\), \(100 + 12\), \(100 + 12\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"3", "4", "1"},
              {"5", "7", "6"},
              {"7", "5", "8"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] =  .8; 
    d = 1 - \[Alpha];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"},
              {"\[Alpha]", "d", "0", "1.", "0"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ";", 
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Mappend;\), "\[IndentingNewLine]", \
\(Mclose;\)}], "Input"],

Cell["Lights", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {"0", "1", "0", "0"},
              {"3", "0", "0", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          "\[IndentingNewLine]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(8/10\), \(0/10\), \(0/10\), "1"},
                  {"0", \(\(-8\)/10\), "0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[DoubleStruckCapitalC]", "=", 
        RowBox[{"2", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.", ".3", ".3"},
                  {".3", ".3", "1."}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], 
      ";"}], "\[IndentingNewLine]", \(\[ScriptCapitalO] = {4, 2};\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["4 Tetrahedra taking over", "Subsubsection"],

Cell[BoxData[{\(Mopen;\), "\[IndentingNewLine]", \(\[Omega] = {\(- .5\), 0, 
          0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"\[ScriptCapitalR]", ".", 
          RowBox[{"(", GridBox[{
                {\(-10\), \(-10\), "10", "10", \(-10\), \(-10\), "10", "10"},
                {"0", "0", "0", "0", "0", "10", "10", "0"},
                {\(-7\), "5", "5", \(-7\), \(-7\), \(-7\), \(-7\), \(-7\)},
                {"0", "0", "0", "0", "0", "0", "0", "0"}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"0", "0", "12", "12", "0", "0", "12", "0"},
              {"100", \(100 + 12\), \(100 + 12\), "100", 
                "100", \(100 + 12\), \(100 + 12\), \(100 + 12\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"3", "4", "1"},
              {"5", "7", "6"},
              {"7", "5", "8"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] =  .5; 
    d =  .5;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"\[Alpha]", "d", "0", "1.", "6"},
              {"\[Alpha]", "d", "0", "1.", "6"},
              {"\[Alpha]", "d", "0", "1.", "6"},
              {"\[Alpha]", "d", "0", "1.", "6"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ";", 
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Mappend;\), "\[IndentingNewLine]", \(fn \
= "\<tetra1\>"; v = { .5, 0, 0, 1}; 
    Mimport\), "\[IndentingNewLine]", \(fn = "\<tetra2\>"; 
    v = {\(- .8\), 0, 0, 1}; 
    Mimport\), "\[IndentingNewLine]", \(fn = "\<tetra3\>"; v = {0, 0, 0, 1}; 
    Mimport\), "\[IndentingNewLine]", \(Mclose;\)}], "Input"],

Cell["Lights", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {"0", "5", "0", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          "\[IndentingNewLine]", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(0/10\), \(0/10\), \(0/10\), "1"},
                  {"0", "0", "0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[DoubleStruckCapitalC]", "=", 
        RowBox[{"2", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1.", "1.", "1."},
                  {"1.", "1.", "1."}
                  },
                RowSpacings->1,
                ColumnSpacings->1,
                ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}]}], 
      ";"}], "\[IndentingNewLine]", \(\[ScriptCapitalO] = {0, 0};\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Primary Refraction **", "Subsubsection"],

Cell[BoxData[{\(Mopen;\), "\[IndentingNewLine]", \(\[Omega] = {0, 0, 
          0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"\[ScriptCapitalR]", ".", 
          RowBox[{"(", GridBox[{
                {\(-10\), \(-10\), "10", "10"},
                {"0", "0", "0", "0"},
                {\(-20\), "5", "5", \(-20\)},
                {"0", "0", "0", "0"}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"0", "0", "12", "12"},
              {"100", \(100 + 24\), \(100 + 24\), "100"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"3", "4", "1"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] =  .5; 
    d =  .5;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"\[Alpha]", "d", "0", "1."},
              {"\[Alpha]", "d", "0", "1."}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ";", 
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Mappend;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"\[ScriptCapitalR]", ".", 
          RowBox[{"(", GridBox[{
                {"0", "5", "2.5", "0", \(-5\), \(-2.5\)},
                {"0", "0", "5", "0", "0", "5"},
                {"0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0"}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"300", "400", "350", "300", "400", "350"},
              {"100", "100", "200", "100", "100", "200"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"4", "6", "5"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] =  .3; 
    d =  .1; \[Rho] = 1 - \[Alpha] - d;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"\[Alpha]", "d", "\[Rho]", "1.5"},
              {"\[Alpha]", "d", "\[Rho]", \(1/1.5\)}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], ";", 
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", ".5", "1"},
                    {"0", "0", ".5", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Mappend;\), "\[IndentingNewLine]", \
\(Mclose;\)}], "Input"],

Cell["Lights", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {"0", "10", \(-10\), "0"},
              {"0", "10", "5", "0"},
              {"0", "10", "0", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{"V", "=", 
      RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
        "\[IndentingNewLine]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(0/10\), \(0/10\), \(0/10\), "1"},
                {"0", "0", "0", "1"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[DoubleStruckCapitalC]", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1", "1"},
                {"1", "1", "1"},
                {"2.5", ".3", ".3"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], 
      ";"}], "\[IndentingNewLine]", \(\[ScriptCapitalO] = {0, 
        0,  .7}\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["3 Earth approaching **", "Subsubsection"],

Cell[BoxData[{\(Mopen;\), "\[IndentingNewLine]", \(\[Omega] = {0, 0, 
          0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"\[ScriptCapitalR]", ".", 
          RowBox[{"(", GridBox[{
                {\(-5\), \(-5\), "5", "5", "5", "5", "5", "5", \(-5\), \(-5\),
                   "5", "5"},
                {\(-3.5\), \(-3.5\), \(-3.5\), \(-3.5\), \(-3.5\), \(-3.5\), 
                  "7", "7", "7", "7", "7", "7"},
                {\(-20\), "5", "5", \(-20\), \(-20\), "5", 
                  "5", \(-20\), \(-20\), "5", "5", \(-20\)},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                }], ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(t = 12;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"0", "0", "t", "t", "0", "0", "t", "t", "0", "0", "t", "t"},
              {"100", \(100 + t\), \(100 + t\), "100", 
                "100", \(100 + t\), \(100 + t\), "100", 
                "100", \(100 + t\), \(100 + t\), "100"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"3", "4", "1"},
              {"5", "6", "7"},
              {"7", "8", "5"},
              {"9", "11", "10"},
              {"11", "9", "12"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(\[Alpha] =  .2;\), \
"\[IndentingNewLine]", \(d =  .8;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"\[Alpha]", "d", "0", "1."},
              {"\[Alpha]", "d", "0", "1."},
              {"\[Alpha]", "d", "0", "1."},
              {"\[Alpha]", "d", "0", "1."},
              {"\[Alpha]", "d", "0", "1."},
              {"\[Alpha]", "d", "0", "1."}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], ";"}], "\[IndentingNewLine]", \(Mappend;\)}], "Input"],

Cell[BoxData[{\(\[Omega] = {0, 0, 0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(fn = "\<dwearth\>"; 
    v = {0, 0,  .8, 1};\), "\[IndentingNewLine]", 
  "Mimport", "\[IndentingNewLine]", \(Mclose;\)}], "Input"],

Cell["Lights", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {"4", "5", "5", "0"},
              {"3", \(-3\), "5", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{"V", "=", 
      RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
        "\[IndentingNewLine]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(0/10\), \(0/10\), \(0/10\), "1"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[DoubleStruckCapitalC]", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1.5", "1.5", "1.5"},
                {"1.2", "1.2", "1.5"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], 
      ";"}], "\[IndentingNewLine]", \(\[ScriptCapitalO] = {0, 0}\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Old Stuff", "Subsubsection"],

Cell[BoxData[
    \(\(Mclose;\)\)], "Input"],

Cell[BoxData[{\(Mopen;\), "\[IndentingNewLine]", \(\[Omega] = {0,  .2, 
          0};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"X", "=", 
          RowBox[{"\[ScriptCapitalR]", ".", 
            RowBox[{"(", GridBox[{
                  {\(-20\), \(-20\), "20", "20", "0", "1", "0", "0", "0", "1",
                     "0", "0"},
                  {"10", \(-10\), \(-10\), "10", "1", "1", "1", "1.5", "1.5", 
                    "1.5", "1.5", "2"},
                  {\(-20\), "5", "5", \(-20\), ".5", "0", \(- .5\), "0", ".5",
                     "0", \(- .5\), "0"},
                  {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
                    "0"}
                  }], ")"}]}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"100", "100", "135", "135", "200", "300", "200", "200", "200", 
                "300", "200", "200"},
              {"200", "235", "235", "200", "100", "150", "200", "150", "100", 
                "150", "200", "150"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"3", "4", "1"},
              {"5", "6", "8"},
              {"8", "6", "7"},
              {"9", "10", "12"},
              {"12", "10", "11"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(d = 1/3;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalM]", "=", 
        RowBox[{"(", GridBox[{
              {"d", "d", "d", "1."},
              {"d", "d", "d", ".7"},
              {"d", "d", "d", "1.2"},
              {"d", "d", "d", ".6"},
              {"d", "d", "d", ".8"},
              {"d", "d", "d", "1.6"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "1"},
                    {".8", "0", "0", "1"},
                    {".8", "0", "0", "1"}
                    }], ")"}], ".", \(\[ScriptT][\[ScriptCapitalR]]\)}], 
            ")"}]}]}], ";"}], "\[IndentingNewLine]", \(Mappend;\)}], "Input"],

Cell[BoxData[{
    \(fn = "\<linsphere\>"; v = {0,  .7,  .6, 1};\), "\[IndentingNewLine]", 
    \(Mimport\), "\[IndentingNewLine]", 
    \(\(Mclose;\)\)}], "Input"],

Cell[BoxData[{\(\[Omega] = {0, \(-\[Pi]\)/3, 0. };\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"\[ScriptCapitalR]", "=", 
        RowBox[{"EXP", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"0", \(x\_3\), \(-x\_2\), "0"},
                  {\(-x\_3\), "0", \(x\_1\), "0"},
                  {\(x\_2\), \(-x\_1\), "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], "\[SmallCircle]", "\[Omega]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(fn = "\<ship50\>"; 
    v = {0, 0, \(- .7\), 1};\), "\[IndentingNewLine]", 
  "Mimport", "\[IndentingNewLine]", \(Mclose;\)}], "Input"],

Cell[BoxData[
    \(\(Mclose;\)\)], "Input"],

Cell[BoxData[{
    \(fn = "\<arch50\>"; v = {0, 0,  .6, 1};\), "\[IndentingNewLine]", 
    \(Mimport\), "\[IndentingNewLine]", 
    \(\(Mclose;\)\)}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {\(-5\), \(-1\), "5", "1", "0", "0", "0"},
              {"0", "0", "0", ".5", ".5", ".5", "1"},
              {\(-5\), "6", \(-5\), "0", ".5", \(- .5\), "0"},
              {"0", "0", "0", "0", "0", "0", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"100", "150", "200", "400", "300", "300", "300", "0", "50", 
                "100"},
              {"0", "100", "0", "50", "100", "0", "50", "0", "100", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"4", "5", "7"},
              {"6", "4", "7"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", GridBox[{
                {"0", "0", "0", "1"},
                {".3", "0", "0", "1"},
                {".3", "0", "0", "1"},
                {"0", "0", "0", "1"},
                {"0", "0", "0", "1"}
                }], ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Mappend;\)}], "Input"],

Cell[BoxData[{
    \(fn = "\<sphere2\>"; v = {\(- .8\), 0, 0, 1};\), "\[IndentingNewLine]", 
    \(Mimport\)}], "Input"],

Cell[BoxData[{
    \(fn = "\<arch100\>"; v = {0, 0,  .6, 1};\), "\[IndentingNewLine]", 
    \(Mimport\)}], "Input"],

Cell[BoxData[{
    \(fn = "\<sphere2\>"; v = {\(- .3\), 0, 0, 1};\), "\[IndentingNewLine]", 
    \(Mimport\)}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"X", "=", 
        RowBox[{"(", GridBox[{
              {\(-5\), \(-1\), "5", "1", "0", "0", "0", \(-5\), "0", "5"},
              {\(-1\), \(-1\), \(-1\), \(- .5\), \(- .5\), \(- .5\), 
                "0", \(-1\), "15", \(-1\)},
              {\(-5\), "6", \(-5\), "0", ".5", \(- .5\), 
                "0", \(-3\), \(-3\), \(-3\)},
              {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{"(", GridBox[{
              {"100", "150", "200", "400", "300", "300", "300", "0", "50", 
                "100"},
              {"0", "100", "0", "50", "100", "0", "50", "0", "100", "0"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "3"},
              {"4", "5", "7"},
              {"6", "4", "7"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        RowBox[{\(\[CapitalMu]Normalize[\[ScriptG], #1] &\), "/@", 
          RowBox[{"(", GridBox[{
                {"0", "0", "0", "1"},
                {".3", "0", "0", "1"},
                {".3", "0", "0", "1"},
                {"0", "0", "0", "1"},
                {"0", "0", "0", "1"}
                }], ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Mappend;\)}], "Input"],

Cell["normal is not speed compliant::::", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Light EXECUTER", "Subsubsection"],

Cell["\<\
We define position, velocity and color of each light. All figures have to be \
entered algebraically.\
\>", "Text"],

Cell[BoxData[{
    \(\(assume = \(#1 \[Element] Reals &\) /@ \[CapitalTau]\[FivePointedStar][
            x, 4];\)\), "\[IndentingNewLine]", 
    \(\(ans = \(Module[{eqs, sol, red, 
                fin}, \[IndentingNewLine]eqs = \((\[ScriptG] . \[CapitalTau]\
\[FivePointedStar][x, 4] . \[CapitalTau]\[FivePointedStar][x, 
                        4])\)\[SmallCircle]\((X\[LeftDoubleBracket]#1\
\[RightDoubleBracket] + \[Tau]\ V\[LeftDoubleBracket]#1\[RightDoubleBracket] \
- \[CapitalTau]\[FivePointedStar][x, 4])\); \[IndentingNewLine]sol = 
                Factor[\[ScriptF][\[Tau] /. 
                      Solve[eqs \[Equal] 
                          0, \[Tau]]]]; \[IndentingNewLine]red = \
\[ScriptS][{sol\[LeftDoubleBracket]1\[RightDoubleBracket] < 
                      sol\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    sol\[LeftDoubleBracket]1\[RightDoubleBracket] > 
                      sol\[LeftDoubleBracket]2\[RightDoubleBracket]}]; \
\[IndentingNewLine]fin = 
                If[red\[LeftDoubleBracket]2\[RightDoubleBracket] === False, 
                    sol\[LeftDoubleBracket]1\[RightDoubleBracket], 
                    sol\[LeftDoubleBracket]2\[RightDoubleBracket]]\
\[SmallCircle]\((P = {pnt\[LeftDoubleBracket]1\[RightDoubleBracket], 
                        pnt\[LeftDoubleBracket]2\[RightDoubleBracket], 
                        pnt\[LeftDoubleBracket]3\[RightDoubleBracket], 
                        pnt\[LeftDoubleBracket]4\[RightDoubleBracket]})\); \
\[IndentingNewLine]fin /. {\[IndentingNewLine]pnt\[LeftDoubleBracket]1\
\[RightDoubleBracket]\^2 \[Rule] 
                    pnt\[LeftDoubleBracket]1\[RightDoubleBracket]\ pnd\
\[LeftDoubleBracket]1\[RightDoubleBracket], \[IndentingNewLine]pnt\
\[LeftDoubleBracket]2\[RightDoubleBracket]\^2 \[Rule] 
                    pnt\[LeftDoubleBracket]2\[RightDoubleBracket]\ pnd\
\[LeftDoubleBracket]2\[RightDoubleBracket], \[IndentingNewLine]pnt\
\[LeftDoubleBracket]3\[RightDoubleBracket]\^2 \[Rule] 
                    pnt\[LeftDoubleBracket]3\[RightDoubleBracket]\ pnd\
\[LeftDoubleBracket]3\[RightDoubleBracket], \[IndentingNewLine]pnt\
\[LeftDoubleBracket]4\[RightDoubleBracket]\^2 \[Rule] 
                    pnt\[LeftDoubleBracket]4\[RightDoubleBracket]\ pnd\
\[LeftDoubleBracket]4\[RightDoubleBracket]}\[IndentingNewLine]] &\) /@ 
          Range[\[ScriptL][X]];\)\), "\[IndentingNewLine]", 
    \(\(os = 
        OpenWrite["\<c:/Dokumente und Einstellungen/Administrator/Eigene \
Dateien/cpp/specrel/lgt_cld.c\>"];\)\), "\[IndentingNewLine]", 
    \(\(ot = 
        OpenWrite["\<c:/Dokumente und Einstellungen/Administrator/Eigene \
Dateien/cpp/specrel/lgt_lum.c\>"];\)\), "\[IndentingNewLine]", 
    \(\(cns = 1;\)\), "\[IndentingNewLine]", 
    \(\(cnt = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(Module[{n}, \[IndentingNewLine]n = 
              cns; \[IndentingNewLine]WriteString[
              os, "\<par[\>", \(cns++\), "\<]=\>", \[IndentingNewLine]CForm[
                SetPrecision[
                  Chop[ans\[LeftDoubleBracket]#1\[RightDoubleBracket]], 
                  7]], "\<;\n\>"]; \[IndentingNewLine]\(WriteString[
                  os, "\<par[\>", \(cns++\), "\<]=\>", #1, "\<;\n\>"] &\) \
/@ \[IndentingNewLine]\(CForm /@ 
                SetPrecision[\[ScriptS][
                    Chop[\[ScriptS][
                        X\[LeftDoubleBracket]#1\[RightDoubleBracket] + 
                          par\[LeftDoubleBracket]n\[RightDoubleBracket]\ V\
\[LeftDoubleBracket]#1\[RightDoubleBracket]]]], 
                  7]\); \[IndentingNewLine]WriteString[
              os, "\<//----\n\>"]; \[IndentingNewLine]\(WriteString[
                  ot, "\<lum[\>", \(cnt++\), "\<]=\>", #1, "\<;\n\>"] &\) /@ \
\(CForm /@ 
                SetPrecision[\[ScriptF][\[DoubleStruckCapitalC]\
\[LeftDoubleBracket]#1\[RightDoubleBracket], 
                    V\[LeftDoubleBracket]#1\[RightDoubleBracket], \
\[ScriptCapitalO]\[LeftDoubleBracket]#1\[RightDoubleBracket]], 
                  5]\); \[IndentingNewLine]WriteString[
              ot, "\<//----\n\>"];\[IndentingNewLine]] &\) /@ 
        Range[\[ScriptL][X]];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[
        os, "\<#define LGT_NUM \>", \[ScriptL][
          X], "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[os, "\<#define LGT_CLD \>", 
        5, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[os, "\<#define LGT_LUM \>", 
        8, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[ot, "\<#define COL_R \>", 
        0, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[ot, "\<#define COL_G \>", 
        1, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[ot, "\<#define COL_B \>", 
        2, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[ot, "\<#define VEL_X \>", 
        3, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[ot, "\<#define VEL_Y \>", 
        4, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[ot, "\<#define VEL_Z \>", 
        5, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[ot, "\<#define VEL_T \>", 
        6, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(WriteString[ot, "\<#define COL_O \>", 
        7, "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(Close[os];\)\), "\[IndentingNewLine]", 
    \(\(Close[ot];\)\)}], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Section"],

Cell[CellGroupData[{

Cell["Polyhedra", "Subsubsection"],

Cell[BoxData[
    \(<< Graphics`Polyhedra`\)], "Input"],

Cell[BoxData[
    \(Show[Polyhedron[shape = Tetrahedron]]\)], "Input"],

Cell[BoxData[{
    \(Vertices[shape] // N\), "\[IndentingNewLine]", 
    \(Faces[shape]\)}], "Input"],

Cell[BoxData[
    \(Show[Geodesate[Polyhedron[Dodecahedron], 4]]\)], "Input"],

Cell[BoxData[
    \(Dodecahedron\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Create animated GIF", "Subsubsection"],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/specrel\>"];\)\), "\[IndentingNewLine]", 
    \(\(load[fn_] := 
        Module[{}, \(AppendTo[maps, 
              Import[fn]];\)];\)\), "\[IndentingNewLine]", 
    \(\(maps = {};\)\), "\[IndentingNewLine]", 
    \(\(load /@ FileNames["\<shot*.bmp\>"];\)\), "\[IndentingNewLine]", 
    \(\(mov = Show /@ maps;\)\), "\[IndentingNewLine]", 
    \(Export["\<c:/specrel/shots\>" <> 
        ToString[Round[SessionTime[]]] <> "\<.gif\>", mov, 
      ConversionOptions \[Rule] {"\<Loop\>" \[Rule] 
            True}]\), "\[IndentingNewLine]", 
    \(Export["\<c:/specrel/shots\>" <> 
        ToString[Round[SessionTime[]]] <> "\<.gif\>", mov, 
      ConversionOptions \[Rule] {"\<Loop\>" \[Rule] 
            True, "\<AnimationDisplayTime\>" \[Rule] 1/3}]\)}], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 938}},
WindowSize->{848, 893},
WindowMargins->{{-1, Automatic}, {5, Automatic}},
ShowSelection->True,
Magnification->1.25,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 47, 0, 83, "Title"],
Cell[1804, 53, 40, 0, 50, "Subtitle"],
Cell[1847, 55, 86, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[1958, 61, 33, 0, 77, "Section"],

Cell[CellGroupData[{
Cell[2016, 65, 47, 0, 56, "Subsubsection"],
Cell[2066, 67, 72, 1, 81, "Input"],
Cell[2141, 70, 158, 2, 104, "Input"],
Cell[2302, 74, 633, 14, 205, "Input"],
Cell[2938, 90, 459, 11, 137, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3434, 106, 35, 0, 56, "Subsubsection"],
Cell[3472, 108, 1100, 23, 451, "Input"],
Cell[4575, 133, 72, 1, 60, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4696, 140, 38, 0, 77, "Section"],

Cell[CellGroupData[{
Cell[4759, 144, 42, 0, 56, "Subsubsection"],
Cell[4804, 146, 236, 4, 123, "Input"],
Cell[5043, 152, 103, 4, 33, "Text"],
Cell[5149, 158, 177, 3, 60, "Input"],
Cell[5329, 163, 169, 3, 60, "Input"],
Cell[5501, 168, 59, 1, 79, "Input"],
Cell[5563, 171, 1928, 44, 375, "Input"],
Cell[7494, 217, 2159, 40, 373, "Input"],
Cell[9656, 259, 2269, 43, 436, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11962, 307, 40, 0, 45, "Subsubsection"],
Cell[12005, 309, 1202, 32, 190, "Input"],
Cell[13210, 343, 692, 18, 123, "Input"],
Cell[13905, 363, 1623, 27, 253, "Input"],
Cell[15531, 392, 2272, 42, 522, "Input"],
Cell[17806, 436, 942, 17, 270, "Input"],
Cell[18751, 455, 67, 0, 33, "Text"],
Cell[18821, 457, 514, 9, 102, "Input"],
Cell[19338, 468, 590, 11, 123, "Input"],
Cell[19931, 481, 79, 1, 79, "Input"],
Cell[20013, 484, 510, 11, 142, "Input"],
Cell[20526, 497, 110, 2, 79, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20685, 505, 28, 0, 77, "Section"],

Cell[CellGroupData[{
Cell[20738, 509, 40, 0, 56, "Subsubsection"],
Cell[20781, 511, 8799, 157, 1655, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29617, 673, 50, 0, 45, "Subsubsection"],
Cell[29670, 675, 3651, 83, 768, "Input"],
Cell[33324, 760, 762, 15, 248, "Input"],
Cell[34089, 777, 22, 0, 33, "Text"],
Cell[34114, 779, 1447, 38, 261, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[35598, 822, 52, 0, 45, "Subsubsection"],
Cell[35653, 824, 2725, 64, 534, "Input"],
Cell[38381, 890, 279, 5, 144, "Input"],
Cell[38663, 897, 44, 1, 60, "Input"],
Cell[38710, 900, 22, 0, 33, "Text"],
Cell[38735, 902, 1326, 34, 193, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[40098, 941, 43, 0, 45, "Subsubsection"],
Cell[40144, 943, 2810, 67, 595, "Input"],
Cell[42957, 1012, 22, 0, 33, "Text"],
Cell[42982, 1014, 1326, 34, 212, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44345, 1053, 46, 0, 45, "Subsubsection"],
Cell[44394, 1055, 2723, 65, 553, "Input"],
Cell[47120, 1122, 22, 0, 33, "Text"],
Cell[47145, 1124, 1323, 34, 214, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48505, 1163, 49, 0, 45, "Subsubsection"],
Cell[48557, 1165, 2947, 69, 576, "Input"],
Cell[51507, 1236, 22, 0, 33, "Text"],
Cell[51532, 1238, 1277, 33, 178, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52846, 1276, 46, 0, 45, "Subsubsection"],
Cell[52895, 1278, 4023, 103, 680, "Input"],
Cell[56921, 1383, 22, 0, 33, "Text"],
Cell[56946, 1385, 1348, 36, 279, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[58331, 1426, 47, 0, 45, "Subsubsection"],
Cell[58381, 1428, 3204, 76, 844, "Input"],
Cell[61588, 1506, 634, 13, 206, "Input"],
Cell[62225, 1521, 22, 0, 33, "Text"],
Cell[62250, 1523, 1231, 32, 193, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[63518, 1560, 34, 0, 45, "Subsubsection"],
Cell[63555, 1562, 44, 1, 60, "Input"],
Cell[63602, 1565, 3140, 77, 730, "Input"],
Cell[66745, 1644, 164, 3, 102, "Input"],
Cell[66912, 1649, 651, 13, 206, "Input"],
Cell[67566, 1664, 44, 1, 60, "Input"],
Cell[67613, 1667, 159, 3, 102, "Input"],
Cell[67775, 1672, 1700, 46, 361, "Input"],
Cell[69478, 1720, 120, 2, 81, "Input"],
Cell[69601, 1724, 115, 2, 81, "Input"],
Cell[69719, 1728, 120, 2, 81, "Input"],
Cell[69842, 1732, 1559, 39, 340, "Input"],
Cell[71404, 1773, 49, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[71490, 1778, 39, 0, 45, "Subsubsection"],
Cell[71532, 1780, 125, 3, 33, "Text"],
Cell[71660, 1785, 5351, 94, 1070, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[77060, 1885, 32, 0, 77, "Section"],

Cell[CellGroupData[{
Cell[77117, 1889, 34, 0, 56, "Subsubsection"],
Cell[77154, 1891, 55, 1, 60, "Input"],
Cell[77212, 1894, 70, 1, 60, "Input"],
Cell[77285, 1897, 101, 2, 81, "Input"],
Cell[77389, 1901, 77, 1, 60, "Input"],
Cell[77469, 1904, 45, 1, 60, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[77551, 1910, 44, 0, 45, "Subsubsection"],
Cell[77598, 1912, 805, 15, 228, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

